aboutsummaryrefslogtreecommitdiff
path: root/module/zfs/vdev_draid.c
diff options
context:
space:
mode:
Diffstat (limited to 'module/zfs/vdev_draid.c')
-rw-r--r--module/zfs/vdev_draid.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/module/zfs/vdev_draid.c b/module/zfs/vdev_draid.c
index 7769ed6a377a..13bb33cc6871 100644
--- a/module/zfs/vdev_draid.c
+++ b/module/zfs/vdev_draid.c
@@ -2548,11 +2548,11 @@ vdev_draid_read_config_spare(vdev_t *vd)
}
/*
* Handle any ioctl requested of the distributed spare. Only flushes
* are supported in which case all children must be flushed.
*/
static int
-vdev_draid_spare_ioctl(zio_t *zio)
+vdev_draid_spare_flush(zio_t *zio)
{
vdev_t *vd = zio->io_vd;
int error = 0;
@@ -2592,8 +2592,8 @@ vdev_draid_spare_io_start(zio_t *zio)
}
switch (zio->io_type) {
- case ZIO_TYPE_IOCTL:
- zio->io_error = vdev_draid_spare_ioctl(zio);
+ case ZIO_TYPE_FLUSH:
+ zio->io_error = vdev_draid_spare_flush(zio);
break;
case ZIO_TYPE_WRITE:
@@ -2548,11 +2548,11 @@ vdev_draid_read_config_spare(vdev_t *vd)
}
/*
- * Handle any ioctl requested of the distributed spare. Only flushes
- * are supported in which case all children must be flushed.
+ * Handle any flush requested of the distributed spare. All children must be
+ * flushed.
*/
static int